summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorYuchi Chen <yuchi.chen@intel.com>2024-06-25 10:48:11 +0800
committerMartin Roth <martin.roth@amd.corp-partner.google.com>2024-08-06 16:48:57 +0000
commitb3c53b1109dfbc40ee7295c089896cb693f5a1fe (patch)
treead09b83ae296f59f31750cdf29706d6abe3d954f /src
parentf61c136f8ab66e550bef0f6dda66fd2656608adb (diff)
soc/intel/common/intelblocks/gpio.h: Allow specifying the pad ownership
Add pad_own_reg_0 to `struct pad_community`. Pad ownership indicates whether the GPIO is owned by host or Intel Management Engine. If owned by host, then host ownership indicates whether the GPIO is owned by ACPI or driver. Change-Id: I30a934fd00a7a42cb156341da1954e4e4b1231d8 Signed-off-by: Yuchi Chen <yuchi.chen@intel.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/83315 Reviewed-by: Shuo Liu <shuo.liu@intel.com> Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Diffstat (limited to 'src')
-rw-r--r--src/soc/intel/common/block/include/intelblocks/gpio.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/soc/intel/common/block/include/intelblocks/gpio.h b/src/soc/intel/common/block/include/intelblocks/gpio.h
index a7bb332344..8e60a1633f 100644
--- a/src/soc/intel/common/block/include/intelblocks/gpio.h
+++ b/src/soc/intel/common/block/include/intelblocks/gpio.h
@@ -121,7 +121,8 @@ struct pad_community {
Number of pads bit mapped in each GPI status/en and Host Own Reg */
gpio_t first_pad; /* first pad in community */
gpio_t last_pad; /* last pad in community */
- uint16_t host_own_reg_0; /* offset to Host Ownership Reg 0 */
+ uint16_t pad_own_reg_0; /* offset to Pad Ownership (host or CSME) Reg 0 */
+ uint16_t host_own_reg_0; /* offset to Host Ownership (ACPI or driver) Reg 0 */
uint16_t gpi_int_sts_reg_0; /* offset to GPI Int STS Reg 0 */
uint16_t gpi_int_en_reg_0; /* offset to GPI Int Enable Reg 0 */
uint16_t gpi_smi_sts_reg_0; /* offset to GPI SMI STS Reg 0 */